/**
 * @file FreeRTOS_Beispiel.c
 */

/**
 * @mainpage Doxygen Getting Started
 *
 * @section sec_1 Einführung
 * 	An dieser Stelle sollte das Programm grob beschrieben werden.
 *
 * @subsection sec_1_1 Beschreibung der Submodule
 * 	... und hier die detaillierte Beschreibung der Submodule
 */

#include "FreeRTOS.h"
#include "task.h"

#define mainDELAY_LOOP_COUNT		( 0xfffff )

void vTask1( void *pvParameters );
void vTask2( void *pvParameters );

/*-----------------------------------------------------------*/

int main( void )
{
	/**
	 * @section sec2 Hauptprogramm
	 *  An dieser Stelle Einfügen einer textlichen Beschreibung des Programmablaufs
	 */
	LPC_PINCON 	-> PINSEL1 &= ~ (3 << 22);
	LPC_GPIO0 	-> FIODIR |= 1 << 22;

	/* Create one of the two tasks. */
	xTaskCreate(	vTask1,		/* Pointer to the function that implements the task. */
					"Task 1",	/* Text name for the task.  This is to facilitate debugging only. */
					240,		/* Stack depth in words. */
					NULL,		/* We are not using the task parameter. */
					1,			/* This task will run at priority 1. */
					NULL );		/* We are not using the task handle. */

	/* Create the other task in exactly the same way. */
	xTaskCreate( vTask2, "Task 2", 240, NULL, 1, NULL );

	/* Start the scheduler so our tasks start executing. */
	vTaskStartScheduler();

	/* If all is well we will never reach here as the scheduler will now be
	running.  If we do reach here then it is likely that there was insufficient
	heap available for the idle task to be created. */
	for( ;; );
	return 0;
}


void vTask1( void *pvParameters )
{
/**
 * Diese Funktion stellt eine Task dar und aktiviert eine LED auf dem Entwicklungsboard.
 *
 * @param[in] pvParameters Parameter zur Taskerstellung (Priority, Stack-Size, etc...)
 * @return kein Rückgabewert
 *
 * @todo Weiterentwicklung der Task.
 *
 * @bug Keine Fehler vorhanden!
 */

/**
 * Folgender Abschnitt kann an dieser Stelle erlaeutert werden <br>
 *
 * @code
 *
 * for( ul = 0; ul < mainDELAY_LOOP_COUNT; ul++ )
 * 		{
 *			printf("Task 1 aktiv\n");
 *			LPC_GPIO0	-> FIOSET |= 1 << 22;
 *		}
 *
 * @endcode
 */
volatile unsigned long ul;

	for( ;; )
	{
		/* Delay for a period. */
		for( ul = 0; ul < mainDELAY_LOOP_COUNT; ul++ )
		{
			printf("Task 1 aktiv\n");
			LPC_GPIO0	-> FIOSET |= 1 << 22;
		}
	}
}


void vTask2( void *pvParameters )
{
/**
 * Diese Funktion stellt eine Task dar und deaktiviert eine LED auf dem Entwicklungsboard.
 *
 * @param[in] pvParameters Parameter zur Taskerstellung (Priority, Stack-Size, etc...)
 * @return kein Rückgabewert
 *
 * @todo Weiterentwicklung der Task.
 *
 * @bug Keine Fehler vorhanden!
 */
volatile unsigned long ul;

	for( ;; )
	{
		/* Delay for a period. */
		for( ul = 0; ul < mainDELAY_LOOP_COUNT; ul++ )
		{
			printf("Task 2 aktiv\n");
			LPC_GPIO0	-> FIOCLR |= 1 << 22;
		}
	}
}

